#
# spec file for package yaml-cpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_name libyaml-cpp0_8
Name:           yaml-cpp
Version:        0.8.0
Release:        2.2
Summary:        YAML parser and emitter in C++
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/jbeder/yaml-cpp/
Source:         https://github.com/jbeder/yaml-cpp/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source98:       baselibs.conf
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  sed
%if %{?suse_version} >= 1330
BuildRequires:  gcc
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc6
BuildRequires:  gcc6-c++
%endif

%description
A YAML parser and emitter in C++ matching the YAML 1.2 spec.

%package -n %{library_name}
Summary:        YAML parser and emitter in C++
Group:          Development/Libraries/C and C++

%description -n %{library_name}
A YAML parser and emitter in C++ matching the YAML 1.2 spec.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{library_name} = %{version}

%description devel
Development files for %{name} library.

%prep
%autosetup -n %{name}-%{version} -p1

%build
export CC=gcc
export CXX=g++
%if 0%{?suse_version} < 1330
export CC=gcc-6
export CXX=g++-6
%endif
%cmake \
    -DYAML_BUILD_SHARED_LIBS:BOOL=ON \
    -DYAML_CPP_BUILD_TESTS:BOOL=OFF \
    -DCMAKE_C_COMPILER=$CC             \
    -DCMAKE_CXX_COMPILER=$CXX

make %{?_smp_mflags}

%install
%cmake_install

%post -n %{library_name} -p /sbin/ldconfig
%postun -n %{library_name} -p /sbin/ldconfig

%files -n %{library_name}
%license LICENSE
%{_libdir}/libyaml-cpp.so.*

%files devel
%{_libdir}/pkgconfig/yaml-cpp.pc
%{_libdir}/cmake/%{name}/
%{_includedir}/yaml-cpp/
%{_libdir}/libyaml-cpp.so

%changelog
* Mon Oct 28 2024 Martin Hauke <mardnh@gmx.de>
- Add baselibs.conf
* Thu Aug 17 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 0.8.0:
  * Significant CMake changes, especially to Windows builds
  * Support for std::unordered_map, std::valarray, and std::string_view
  * Updated gtest dependency
  * Assorted bug fixes
- Drop 1077.patch, which is included in version 0.8.0
* Thu May 11 2023 Frederic Crozat <fcrozat@suse.com>
- Drop patches fix-cmake-export.patch  untabify-cmakelists.patch
  replacing them with pull-request 1077.patch which was
  merged (bsc#1191137).
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- add fix-cmake-export.patch  untabify-cmakelists.patch (bsc#1191137)
* Mon Aug 30 2021 Hans-Peter Jansen <hpj@urpla.net>
- Adjust library dependency reference
* Mon Aug 30 2021 Stanislav Brabec <sbrabec@suse.com>
- Update to 0.7.0:
  * Bazel support
  * CMake improvements
  * Adopts many modern C++ syntaxes
  * Bug fixes
  * Obsoletes yaml-cpp-CVE-2017-5950.patch (fixed by DepthGuard)
* Tue Dec 17 2019 Michał Rostecki <mrostecki@opensuse.org>
- Update to 0.6.3:
  * bug fixes
  * CMake updates, now requiring 3.1
- Remove merged patch to fix PIE build:
  * yaml-cpp-fix-pie.patch
* Thu Aug  9 2018 rpm@fthiessen.de
- Update to 0.6.2:
  * Fix incorrect version numbering
* Wed Feb 14 2018 pmonrealgonzalez@suse.com
- Security fix: [bsc#1032144, CVE-2017-5950]
  * Stack overflow in SingleDocParser::HandleNode() function
  * Added patch yaml-cpp-CVE-2017-5950.patch
* Fri Feb  2 2018 tchvatal@suse.com
- Update to 0.6.1:
  * Just brownpaperbag over previous release
* Wed Jan 31 2018 pmonrealgonzalez@suse.com
- Update to version 0.6.0
  * yaml-cpp no longer depends on Boost
  * Requires C++11
  * Some bug fixes and performance improvements
- Dropped patch yaml-cpp-disable-bundled-gmock.patch since it can
  be configured with the option YAML_CPP_BUILD_TESTS
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Jul 11 2016 tchvatal@suse.com
- Fix building with updated cmake and wrong -fPIE parsing:
  * yaml-cpp-disable-bundled-gmock.patch
  * yaml-cpp-fix-pie.patch
* Fri Feb 12 2016 mpluskal@suse.com
- Update to 0.5.3
  * Bugfix release.
  * This will be the last release that does not require C++11.
- Drop upstreamed fix-node-regression.patch
- Small spec file cleanups
* Fri Nov 13 2015 tchvatal@suse.com
- Add patch to fix wrong node behaviour in 0.5.2 bnc#954749:
  * fix-node-regression.patch
* Sat Aug  1 2015 rpm@fthiessen.de
- Update version 0.5.2
  * Some bugfixes
- Updated spec file
  * Using cmake macro
  * Updated copyright.
* Tue Jul  2 2013 asterios.dramis@gmail.com
- Added boost-devel in yaml-cpp-devel Requires: (some yaml-cpp headers require
  boost headers).
* Sat Jun 29 2013 i@marguerite.su
- update version 0.5.1
  * a bug fix release for the new API
* Sun Jul 22 2012 i@marguerite.su
- fix sle builds.
* Sun Jul 22 2012 i@marguerite.su
- update version 0.3.0
  * minor bug fixing release
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Mon Nov 14 2011 tchvatal@suse.com
- Initial commit of yaml-cpp.
